Use the right wording in DCHECK_IS_ON() presubmit check.

It was added in https://codereview.chromium.org/1407033004/ but
used the word braces for the parentheses.

NOTRY=True

Review-Url: https://codereview.chromium.org/2705303004
Cr-Commit-Position: refs/heads/master@{#452163}
diff --git a/PRESUBMIT.py b/PRESUBMIT.py
index 6334c05..e56d4b3 100644
--- a/PRESUBMIT.py
+++ b/PRESUBMIT.py
@@ -431,7 +431,7 @@
 
 
 def _CheckDCHECK_IS_ONHasBraces(input_api, output_api):
   """Checks to make sure DCHECK_IS_ON() does not skip the braces."""
   errors = []
   pattern = input_api.re.compile(r'DCHECK_IS_ON(?!\(\))',
                                  input_api.re.MULTILINE)
@@ -442,7 +442,7 @@
       if input_api.re.search(pattern, line):
         errors.append(output_api.PresubmitError(
           ('%s:%d: Use of DCHECK_IS_ON() must be written as "#if ' +
-           'DCHECK_IS_ON()", not forgetting the braces.')
+           'DCHECK_IS_ON()", not forgetting the parentheses.')
           % (f.LocalPath(), lnum)))
   return errors
@@ -431,7 +431,7 @@
 
 def _CheckDCHECK_IS_ONHasBraces(input_api, output_api):
-  """Checks to make sure DCHECK_IS_ON() does not skip the braces."""
+  """Checks to make sure DCHECK_IS_ON() does not skip the parentheses."""
   errors = []
   pattern = input_api.re.compile(r'DCHECK_IS_ON(?!\(\))',